---
name: Bug report
about: Create a bug report to help improve pyrekordbox
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
````python
...
````
The resulting error is:
> ...

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment**
- pyrekordbox version:
- OS and Python version:

**Additional context**
Add any other context about the problem here.
